@@ -3,20 +3,19 @@
  * Copyright (C) 2006 Xavier Claessens <xclaesse@gmail.com>
  * Copyright (C) 2007 Collabora Ltd.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  * Authors: Xavier Claessens <xclaesse@gmail.com>
  */
@@ -358,6 +357,7 @@ tp_group_get_members_cb (DBusGProxy *proxy,
 	if (error) {
 		empathy_debug (DEBUG_DOMAIN, "Failed to get members: %s",
 			       error->message);
+		g_object_unref (group);
 		return;
 	}
 
@@ -372,6 +372,7 @@ tp_group_get_members_cb (DBusGProxy *proxy,
 				     group);
 
 	g_array_free (handles, TRUE);
+	g_object_unref (group);
 }
 
 static void
@@ -388,6 +389,7 @@ tp_group_get_local_pending_cb (DBusGProxy *proxy,
 	if (error) {
 		empathy_debug (DEBUG_DOMAIN, "Failed to get local pendings: %s",
 			       error->message);
+		g_object_unref (group);
 		return;
 	}
 
@@ -420,6 +422,7 @@ tp_group_get_local_pending_cb (DBusGProxy *proxy,
 	}
 	g_ptr_array_free (array, TRUE);
 	g_array_free (handles, TRUE);
+	g_object_unref (group);
 }
 
 static void
@@ -434,6 +437,7 @@ tp_group_get_remote_pending_cb (DBusGProxy *proxy,
 	if (error) {
 		empathy_debug (DEBUG_DOMAIN, "Failed to get remote pendings: %s",
 			       error->message);
+		g_object_unref (group);
 		return;
 	}
 
@@ -448,6 +452,7 @@ tp_group_get_remote_pending_cb (DBusGProxy *proxy,
 				     group);
 
 	g_array_free (handles, TRUE);
+	g_object_unref (group);
 }
 
 static void
@@ -455,6 +460,8 @@ tp_group_finalize (GObject *object)
 {
 	EmpathyTpGroupPriv *priv = GET_PRIV (object);
 
+	empathy_debug (DEBUG_DOMAIN, "finalize: %p");
+
 	tp_group_disconnect (EMPATHY_TP_GROUP (object));
 
 	if (priv->tp_chan) {
@@ -552,13 +559,13 @@ empathy_tp_group_new (McAccount *account,
 	EmpathyTpGroup     *group;
 	EmpathyTpGroupPriv *priv;
 	DBusGProxy         *group_iface;
-	GError             *error;
+	GError             *error = NULL;
 
 	g_return_val_if_fail (TELEPATHY_IS_CHAN (tp_chan), NULL);
 	g_return_val_if_fail (MC_IS_ACCOUNT (account), NULL);
 
 	group_iface = tp_chan_get_interface (tp_chan,
-					     TELEPATHY_CHAN_IFACE_GROUP_QUARK);
+					     TP_IFACE_QUARK_CHANNEL_INTERFACE_GROUP);
 	g_return_val_if_fail (group_iface != NULL, NULL);
 
 	group = g_object_new (EMPATHY_TYPE_TP_GROUP, NULL);
@@ -590,13 +597,13 @@ empathy_tp_group_new (McAccount *account,
 
 	tp_chan_iface_group_get_members_async (priv->group_iface,
 					       tp_group_get_members_cb,
-					       group);
+					       g_object_ref (group));
 	tp_chan_iface_group_get_local_pending_members_with_info_async (priv->group_iface,
 								       tp_group_get_local_pending_cb,
-								       group);
+								       g_object_ref (group));
 	tp_chan_iface_group_get_remote_pending_members_async (priv->group_iface,
 							      tp_group_get_remote_pending_cb,
-							      group);
+							      g_object_ref (group));
 
 	return group;
 }
@@ -777,7 +784,7 @@ empathy_tp_group_get_name (EmpathyTpGroup *group)
 	priv = GET_PRIV (group);
 
 	/* Lazy initialisation */
-	if (!priv->group_name) {
+	if (!priv->group_name && priv->tp_chan->handle != 0) {
 		priv->group_name = empathy_inspect_channel (priv->account, priv->tp_chan);
 	}
 
